
/*	Copyright (c) 2001, ATAPY Software. All rights reserved.

	This file is part of Pdf2Bmp. 
	
	Pdf2Bmp is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Pdf2Bmp is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __GS651WRP_H 
#define __GS651WRP_H 

#include <Windows.h> 

#include <GSDLL.h> 

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//

class CGS651Wrapper; 
class CGS651Parser; 

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//

class CGS651Wrapper { 
public: 
	CGS651Wrapper(); 

	bool Load( const char* fileName ); 
	bool CheckRevision() const; 

	int InitializeInstance( GSDLL_CALLBACK callback, HWND hwnd, 
		int argc, char** argv ) const; 
	int DeinitializeInstance() const; 

	int RunScript( const char* script ) const; 

private: 
	typedef int ( __stdcall/*GSDLLAPI*/ *GetRevisionFunc ) 
		( char**, char**, long*, long* ); 
	typedef int ( __stdcall/*GSDLLAPI*/ *InitializeInstanceFunc ) 
		( GSDLL_CALLBACK, HWND, int, char** ); 
	typedef int ( __stdcall/*GSDLLAPI*/ *DeinitializeInstanceFunc ) 
		(); 

	typedef int ( __stdcall/*GSDLLAPI*/ *ProcessStringStartFunc ) 
		(); 
	typedef int ( __stdcall/*GSDLLAPI*/ *ProcessStringContinueFunc ) 
		( const char*, int ); 
	typedef int ( __stdcall/*GSDLLAPI*/ *ProcessStringEndFunc ) 
		(); 

	HINSTANCE hInstance; 
	GetRevisionFunc getRevisionFunc; 
	InitializeInstanceFunc initializeInstanceFunc; 
	DeinitializeInstanceFunc deinitializeInstanceFunc; 

	ProcessStringStartFunc processStringStartFunc; 
	ProcessStringContinueFunc processStringContinueFunc; 
	ProcessStringEndFunc processStringEndFunc; 

	static const int maxStringPartLength; 
	static const int minRevisionVersion; 

private: 
	void reset(); 
	bool loadLibrary( const char* fileName ); 

	int getRevision( char** product, char** copyright, 
		long* revision, long* date ) const; 

	int initializeInstance( GSDLL_CALLBACK callback, HWND wnd, 
		int argc, char** argv ) const; 
	int deinitializeInstance() const; 

	int processStringStart() const; 
	int processStringContinue( const char* string, int length ) const; 
	int processStringEnd() const; 

};

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//

class CGS651Parser { 
public: 
	~CGS651Parser(); 
	CGS651Parser( const char* fileName, 
		const char* gsdllFolder, 
		const char* gsdllName ); 

	int Load(); 

	int GetPageCount( const char* fileName ) const; 
	int OpenPage( int pageNumber, 
		const char* fileName, const char* deviceName,
		int xResolution, int yResolution ); 

private: 
	const char* fileName; 
	const char* dllFolder; 
	const char* dllFileName; 

	CGS651Wrapper wrapper; 

private: 
	int getPageCount( const char* fileName ) const; 
	int openPage( int pageNumber, 
		const char* fileName, const char* deviceName,
		int xResolution, int yResolution ) const; 

	const char* createGetPageCountPostScriptString( 
		const char* fileName ) const; 
	const char* createOpenPagePostScriptString( 
		int page ) const; 

	const char* createExtraPathString() const; 
	const char* createNoPauseString() const; 
	const char* createOutputFormatString( const char* deviceName ) const; 
	const char* createResolutionString( char ch, int resolution ) const; 
	const char* createOutputFileString( const char* fileName ) const; 
	const char* createExtraFontPathString() const;

};

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//

#endif //	__GS651WRP_H 
