/*	Copyright (c) 2001, ATAPY Software. All rights reserved.

	This file is part of Pdf2Bmp. 
	
	Pdf2Bmp is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Pdf2Bmp is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __GS700WRP_H 
#define __GS700WRP_H 

#include <Windows.h> 

#include <IAPI.h> 
#include <errors.h> 
//#include <GSErrors.h> 

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//

class CGS700Wrapper; 
class CGS700Parser; 

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//

class CGS700Wrapper { 
public: 
	CGS700Wrapper(); 

	bool Load( const char* fileName ); 
	bool CheckRevision() const; 

	gs_main_instance* CreateInstance() const; 
	void DeleteInstance( gs_main_instance* instance ) const; 

	int InitializeInstance( gs_main_instance* instance, 
		int argc, char** argv ) const; 
	int DeinitializeInstance( gs_main_instance* instance ) const; 

	int RunScript( gs_main_instance* instance, 
		const char* script ) const; 

private: 
	typedef int ( __stdcall/*GSDLLAPI*/ *GetRevisionFunc ) 
		( gsapi_revision_t*, int ); 
	typedef int ( __stdcall/*GSDLLAPI*/ *CreateInstanceFunc ) 
		( gs_main_instance**, void* ); 
	typedef int ( __stdcall/*GSDLLAPI*/ *InitializeInstanceFunc ) 
		( gs_main_instance*, int, char** ); 
	typedef int ( __stdcall/*GSDLLAPI*/ *DeinitializeInstanceFunc ) 
		( gs_main_instance* ); 
	typedef void ( __stdcall/*GSDLLAPI*/ *DeleteInstanceFunc ) 
		( gs_main_instance* ); 

	typedef int ( __stdcall/*GSDLLAPI*/ *ProcessStringStartFunc ) 
		( gs_main_instance*, int, int* ); 
	typedef int ( __stdcall/*GSDLLAPI*/ *ProcessStringContinueFunc ) 
		( gs_main_instance*, const char*, unsigned int, int, int* ); 
	typedef int ( __stdcall/*GSDLLAPI*/ *ProcessStringEndFunc ) 
		( gs_main_instance*, int, int* ); 

	HINSTANCE hInstance; 
	GetRevisionFunc getRevisionFunc; 
	CreateInstanceFunc createInstanceFunc; 
	InitializeInstanceFunc initializeInstanceFunc; 
	DeinitializeInstanceFunc deinitializeInstanceFunc; 
	DeleteInstanceFunc deleteInstanceFunc; 

	ProcessStringStartFunc processStringStartFunc; 
	ProcessStringContinueFunc processStringContinueFunc; 
	ProcessStringEndFunc processStringEndFunc; 

	static const int maxStringPartLength; 
	static const int minRevisionVersion; 

private: 
	void reset(); 
	bool loadLibrary( const char* fileName ); 

	int getRevision( gsapi_revision_t& revision ) const; 

	gs_main_instance* createInstance() const; 
	void deleteInstance( gs_main_instance* instance ) const; 
	int initializeInstance( gs_main_instance* instance, 
		int argc, char** argv ) const; 
	int deinitializeInstance( gs_main_instance* instance ) const; 

	int processStringStart( gs_main_instance* instance ) const; 
	int processStringContinue( gs_main_instance* instance, 
		const char* string, int length ) const; 
	int processStringEnd( gs_main_instance* instance ) const; 

};

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//

class CGS700Parser { 
public: 
	~CGS700Parser(); 
	CGS700Parser( const char* fileName, 
		const char* gsdllFolder, 
		const char* gsdllName ); 

	int Load(); 

	int GetPageCount( const char* fileName ) const; 
	int OpenPage( int pageNumber, const char* fileName, 
		const char* deviceName, int xResolution, int yResolution ); 

private: 
	const char* fileName; 
	const char* dllFolder; 
	const char* dllFileName; 

	CGS700Wrapper wrapper; 
	gs_main_instance* instance; 

private: 
	int getPageCount( const char* fileName ) const; 
	int openPage( int pageNumber, 
		const char* fileName, const char* deviceName,
		int xResolution, int yResolution ) const; 

	const char* createGetPageCountPostScriptString( 
		const char* fileName ) const; 
	const char* createOpenPagePostScriptString( 
		int page ) const; 

	const char* createExtraPathString() const; 
	const char* createNoPauseString() const; 
	const char* createOutputFormatString( const char* deviceName ) const; 
	const char* createResolutionString( char ch, int resolution ) const; 
	const char* createOutputFileString( const char* fileName ) const; 
	const char* CGS700Parser::createExtraFontPathString() const;
};

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//

#endif //	__GS700WRP_H 
